#
# Imports
#
import sys
import sliderule
from utils import parse_command_line
from sliderule import earthdata

###############################################################################
# MAIN
###############################################################################

if __name__ == '__main__':

    # Defaults
    cfg = {
        "region": "tests/data/grandmesa.geojson",
        "tolerance": 0.0,
        "dataset": "ATL03",
        "version": "006",
    }

    # Command line parameters
    parse_command_line(sys.argv, cfg)

    # Override region of interest
    region = sliderule.toregion(cfg["region"], cfg["tolerance"])

    # Query CMR for list of resources
    resources = earthdata.cmr(short_name=cfg["dataset"], version=cfg["version"], polygon=region["poly"])
    print("Region: {} points, {} files".format(len(region["poly"]), len(resources)))
    for resource in resources:
        print(resource)



#
# Uses the icesat2.h5p api to read a dataset from an H5 file and write the contents to a file
#

import sys
from sliderule import h5
from utils import parse_command_line, initialize_client

###############################################################################
# MAIN
###############################################################################

if __name__ == '__main__':

    # set script defaults
    local = {
        "dataset":      '/gt2l/heights/h_ph',
        "col":          0,
        "startrow":     0,
        "numrows":      -1
    }

    # Initialize Client
    parms, cfg = initialize_client(sys.argv)

    # parse configuration parameters
    parse_command_line(sys.argv, local)

    # Read Dataset #
    datasets = [ {"dataset": local["dataset"], "col": local["col"], "startrow": local["startrow"], "numrows": local["numrows"]} ]
    rawdata = h5.h5p(datasets, cfg["resource"], cfg["asset"])
    print(rawdata)

    # Write Dataset to File #
    filename = local["dataset"][local["dataset"].rfind("/")+1:]
    f = open(filename + ".bin", 'w+b')
    f.write(bytearray(rawdata[local["dataset"]]))
    f.close()



#
# Imports
#
import sys
import json
import sliderule
from utils import parse_command_line
from sliderule import earthdata

###############################################################################
# MAIN
###############################################################################

if __name__ == '__main__':

    # Defaults
    cfg = {
        "dataset": "HLS",
        "region": "examples/grandmesa.geojson",
        "time_start": "2021-01-01T00:00:00Z",
        "time_end": "2022-01-01T23:59:59Z",
        "display_all": False
    }

    # Command line parameters
    parse_command_line(sys.argv, cfg)

    # Region of interest
    polygon = sliderule.toregion(cfg["region"])["poly"]

    # Query CMR for list of resources
    geojson = earthdata.stac(short_name=cfg["dataset"], polygon=polygon, time_start=cfg["time_start"], time_end=cfg["time_end"])

    # Display Results
    print("Returned {} features".format(geojson["context"]["returned"]))
    if cfg["display_all"]:
        print(json.dumps(geojson, indent=2))




import os
import sys
import configparser
import sliderule
from sliderule import icesat2
from utils import initialize_client

# Read AWS Credentials #
home_directory = os.path.expanduser( '~' )
aws_credential_file = os.path.join(home_directory, '.aws', 'credentials')
config = configparser.RawConfigParser()
config.read(aws_credential_file)

# Get AWS Credentials #
ACCESS_KEY_ID = config.get('default', 'aws_access_key_id')
SECRET_ACCESS_KEY_ID = config.get('default', 'aws_secret_access_key')
SESSION_TOKEN = config.get('default', 'aws_session_token')

# Initialize SlideRule Client #
parms, cfg = initialize_client(sys.argv)

# Set Output Parameters #
parms["output"] = {
    "path": "s3://sliderule/config/testfile.parquet",
    "format": "parquet",
    "open_on_complete": False,
    "region": "us-west-2",
    "credentials": {
        "aws_access_key_id": ACCESS_KEY_ID,
        "aws_secret_access_key": SECRET_ACCESS_KEY_ID,
        "aws_session_token": SESSION_TOKEN
    }
}

# Run Processing Request #
gdf = icesat2.atl06p(parms, asset=cfg["asset"], resources=[cfg["resource"]])
